function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from "react";
import { unstable_trace as trace } from "scheduler/tracing";
import { beautifyKey, updateValue } from "@ui-schema/ui-schema";
import { ValidityHelperText } from "../Component/LocaleHelperText";

const StringRenderer = ({
  ownKey,
  schema,
  value,
  multiline,
  onChange,
  storeKeys,
  showValidity,
  required,
  errors,
  type,
  rows
}) => {
  const format = schema.get('format');
  let Renderer = 'input';

  if (multiline) {
    Renderer = 'textarea';
  }

  let classFormGroup = ["form-group"];
  let classFormControl = ["form-control"];

  if (showValidity && errors.size) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.size) {
    classFormGroup.push('was-validated');
  }

  return React.createElement("div", {
    className: classFormGroup.join(' ')
  }, React.createElement("label", {
    htmlFor: ownKey
  }, beautifyKey(ownKey)), React.createElement(Renderer, {
    className: classFormControl.join(' '),
    type: format || type,
    required: required,
    rows: rows,
    value: typeof value !== 'undefined' ? value : '',
    onChange: e => trace("textfield onchange", performance.now(), () => {
      const value = e.target.value;
      const target = e.target;

      if (type === 'number') {
        if (isNaN(value * 1)) {
          console.error('Invalid Type: input not a number in:', target);
          return;
        }

        onChange(updateValue(storeKeys, value * 1));
      } else {
        onChange(updateValue(storeKeys, value));
      }
    })
  }), React.createElement(ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
};

const TextRenderer = (_ref) => {
  let {
    schema
  } = _ref,
      props = _objectWithoutProperties(_ref, ["schema"]);

  return React.createElement(StringRenderer, _extends({}, props, {
    schema: schema,
    rows: schema.getIn(['view', 'rows']),
    multiline: true
  }));
};

const NumberRenderer = (_ref2) => {
  let {
    schema
  } = _ref2,
      props = _objectWithoutProperties(_ref2, ["schema"]);

  return React.createElement(StringRenderer, _extends({}, props, {
    schema: schema,
    type: 'number'
  }));
};

export { StringRenderer, NumberRenderer, TextRenderer };